@@ -18,34 +18,22 @@ OC.L10N.register(
     "All articles" : "Alle artikels",
     "Explore" : "Ontdek",
     "Settings" : "Instellings",
+    "Documentation" : "Dokumentasie",
     "Keyboard shortcuts" : "Sneltoetse",
     "Rename" : "Hernoem",
     "Delete" : "Skrap",
     "Newest first" : "Nuutste eerste",
     "Oldest first" : "Oudste eerste",
     "by" : "deur",
-    "from" : "van",
     "Play audio" : "Speel oudio af",
     "Download audio" : "Laai oudio af",
     "Download video" : "Laai video af",
+    "Folder" : "Vouer",
     "Keyboard shortcut" : "Snelsleutel",
     "Jump to next article" : "Spring na volgende artikel",
     "Jump to previous article" : "Spring na vorige artikel",
     "right" : "regs",
     "left" : "links",
-    "Refresh" : "Verfris",
-    "Description" : "Beskrywing",
-    "Folder" : "Vouer",
-    "Go back" : "Gaan terug",
-    "New Folder" : "Nuwe Vouer",
-    "Create" : "Skep",
-    "Menu" : "Kieslys",
-    "Dismiss" : "Wys Af",
-    "Collapse" : "Vou In",
-    "Deleted folder" : "Geskrapte vouer",
-    "Import" : "Voer In",
-    "Export" : "Stuur Uit",
-    "Help" : "Hulp",
-    "Documentation" : "Dokumentasie"
+    "Refresh" : "Verfris"
 },
 "nplurals=2; plural=(n != 1);");
