@@ -28,6 +28,7 @@ OC.L10N.register(
     "How many redirects the feed fetcher should follow." : "Hversu mörgum endurbeiningum streymissugan á að fylgja.",
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Hámarksfjöldi sekúndna sem beðið er eftir að RSS eða Atom-streymi hlaðist inn; ef það tekur lengri tíma er hætt við uppfærslu.",
     "Interval in seconds in which the feeds will be updated." : "Tími í sekúndum sem líður milli þess sem streymi eru uppfærð.",
+    "Show all articles" : "Birta allar greinar",
     "Move" : "Færa",
     "Share" : "Deila",
     "Share with" : "Deila með",
@@ -42,7 +43,6 @@ OC.L10N.register(
     "Documentation" : "Hjálparskjöl",
     "Keyboard shortcuts" : "Flýtilyklar",
     "Disable mark read through scrolling" : "Gera óvirkt að merkja sem lesið við skrun",
-    "Show all articles" : "Birta allar greinar",
     "Reverse ordering (oldest on top)" : "Öfug röðun (elsta efst)",
     "Rename" : "Endurnefna",
     "Delete" : "Eyða",
@@ -54,8 +54,6 @@ OC.L10N.register(
     "Default order" : "Sjálfgefin röðun",
     "Enable full text" : "Virkja allan texta",
     "Disable full text" : "Afvirkja allan texta",
-    "Previous" : "Fyrra",
-    "Next" : "Næst",
     "Toggle star article" : "Víxla stjörnumerkingu af/á grein",
     "Mark unread" : "Merkja sem ólesið",
     "Close details" : "Loka nánari upplýsingum",
@@ -68,6 +66,7 @@ OC.L10N.register(
     "Toggle keep current article unread" : "Víxla af/á að halda greininni sem ólesinni",
     "Remove keep article unread" : "Fjarlægja að halda greininni sem ólesinni",
     "Please wait" : "Bíddu aðeins",
+    "Folder" : "Mappa",
     "Keyboard shortcut" : "Flýtilykill",
     "Action" : "Aðgerð",
     "Jump to next article" : "Hoppa á næstu grein",
